<?php
/**
 * Plugin Name: Social Widget
 */

add_action( 'widgets_init', 'classiera_social_load_widget' );

function classiera_social_load_widget() {
	register_widget( 'classiera_social_widget' );
}

class classiera_social_widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function classiera_social_widget() {
		
			/* Widget settings. */
			$widget_ops = array( 'classname' => 'classiera_social_widget', 'description' => esc_html__('A widget that displays your social icons', 'classiera') );

			/* Widget control settings. */
			$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => 'classiera_social_widget' );

			/* Create the widget. */
			$this->__construct( 'classiera_social_widget', esc_html__('Classiera: Social Icons', 'classiera'), $widget_ops, $control_ops );
		
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );
		global $redux_demo;
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$facebook = $instance['facebook'];
		$twitter = $instance['twitter'];
		$googleplus = $instance['googleplus'];
		$bloglovin = $instance['bloglovin'];
		$youtube = $instance['youtube'];
		$tumblr = $instance['tumblr'];
		$pinterest = $instance['pinterest'];
		$rss = $instance['rss'];
		
		/* Before widget (defined by themes). */
		echo wp_kses_post($before_widget);

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			?>
		<div class="widgetTitle">
			<i class="fa fa-share-alt"></i>
		<?php
			echo wp_kses_post($before_title) . $title . $after_title;

		?>
		</div>
		
		<div class="widgetContent">
			<div class="socialShare">
				<ul class="inline-list">
					<?php if($facebook) : ?><li><a href="<?php echo $redux_demo['facebook-link']; ?>" target="_blank"><i class="fa fa-facebook"></i></a></li><?php endif; ?>
					<?php if($twitter) : ?><li><a href="<?php echo $redux_demo['twitter-link']; ?>" target="_blank"><i class="fa fa-twitter"></i></a></li><?php endif; ?>
					
					<?php if($pinterest) : ?><li><a href="<?php echo $redux_demo['pinterest-link']; ?>" target="_blank"><i class="fa fa-pinterest"></i></a></li><?php endif; ?>
					<?php if($bloglovin) : ?><li><a href="<?php echo $redux_demo['flickr-link']; ?>" target="_blank"><i class="fa fa-flickr"></i></a></li><?php endif; ?>
					<?php if($googleplus) : ?><li><a href="<?php echo $redux_demo['google-plus-link']; ?>" target="_blank"><i class="fa fa-google-plus"></i></a></li><?php endif; ?>
					<?php if($tumblr) : ?><li><a href="<?php echo $redux_demo['tumblr-link']; ?>" target="_blank"><i class="fa fa-tumblr"></i></a></li><?php endif; ?>
					<?php if($youtube) : ?><li><a href="<?php echo $redux_demo['youtube-link']; ?>" target="_blank"><i class="fa fa-youtube-play"></i></a></li><?php endif; ?>
					<?php if($rss) : ?><li><a href="<?php echo $redux_demo['vimeo-link']; ?>" target="_blank"><i class="fa fa-vimeo"></i></a></li><?php endif; ?>
				</ul>
			</div>
		</div>	
			
		<?php

		/* After widget (defined by themes). */
		echo wp_kses_post($after_widget);
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['facebook'] = strip_tags( $new_instance['facebook'] );
		$instance['twitter'] = strip_tags( $new_instance['twitter'] );
		$instance['googleplus'] = strip_tags( $new_instance['googleplus'] );
		$instance['bloglovin'] = strip_tags( $new_instance['bloglovin'] );
		$instance['youtube'] = strip_tags( $new_instance['youtube'] );
		$instance['tumblr'] = strip_tags( $new_instance['tumblr'] );
		$instance['pinterest'] = strip_tags( $new_instance['pinterest'] );
		$instance['rss'] = strip_tags( $new_instance['rss'] );

		return $instance;
	}


	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => 'Subscribe & Follow', 'facebook' => 'on', 'twitter' => 'on', 'pinterest' => 'on', 'bloglovin' => '', 'tumblr' => '', 'rss' => '', 'googleplus' => 'on', 'youtube' => 'on', );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>">Title:</label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($instance['title']); ?>" style="width:90%;" />
		</p>
		
		<p>Note: Set your social links in the Customizer</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'facebook' )); ?>">Show Facebook:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'facebook' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'facebook' )); ?>" <?php checked( (bool) $instance['facebook'], true ); ?> />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'twitter' )); ?>">Show Twitter:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'twitter' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'twitter' )); ?>" <?php checked( (bool) $instance['twitter'], true ); ?> />
		</p>
		
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'pinterest' )); ?>">Show Pinterest:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'pinterest' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'pinterest' )); ?>" <?php checked( (bool) $instance['pinterest'], true ); ?> />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'bloglovin' )); ?>">Show Flicker:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'bloglovin' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'bloglovin' )); ?>" <?php checked( (bool) $instance['bloglovin'], true ); ?> />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'googleplus' )); ?>">Show Google Plus:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'googleplus' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'googleplus' )); ?>" <?php checked( (bool) $instance['googleplus'], true ); ?> />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'tumblr' )); ?>">Show Tumblr:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'tumblr' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'tumblr' )); ?>" <?php checked( (bool) $instance['tumblr'], true ); ?> />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'youtube' )); ?>">Show Youtube:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'youtube' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'youtube' )); ?>" <?php checked( (bool) $instance['youtube'], true ); ?> />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'rss' )); ?>">Show vimeo:</label>
			<input type="checkbox" id="<?php echo esc_attr($this->get_field_id( 'rss' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'rss' )); ?>" <?php checked( (bool) $instance['rss'], true ); ?> />
		</p>


	<?php
	}
}

?>